==> sycommon_python_lib-0.1.8.tar.gz: sycommon_python_lib-0.1.8/src/sycommon/models/base_http.py <==
from typing import TypeVar, Any, Generic
from pydantic import BaseModel, Field
from fastapi.responses import JSONResponse
from fastapi import status

# 修改泛型约束，支持任意类型（包括基础类型和BaseModel）
T = TypeVar('T')


class BaseResponseModel(BaseModel, Generic[T]):
    """基础响应模型，支持多种数据类型（包括字符串、字典和Pydantic模型）"""
    code: int = Field(default=0, description="业务响应码，成功0，失败非0")
    message: str = Field(default="success", description="业务响应信息")
    data: T | None = Field(default=None, description="业务响应数据，支持任意类型")
    traceId: str | None = Field(default=None, description="请求链路追踪ID")

    class Config:
        arbitrary_types_allowed = True
        from_attributes = True


def build_response_content(
    data: T | Any = None,
    code: int = 0,
    message: str = "success"
) -> dict:
    """
    只构建响应内容的字典部分

    Args:
        data: 响应数据（支持字符串、字典、Pydantic模型等）
        code: 业务响应码
        message: 响应信息

    Returns:
        响应内容字典，格式为{"code": int, "message": str, "data": Any}
    """
    response = BaseResponseModel(
        code=code,
        message=message,
        data=data
    )

    if isinstance(response.data, BaseModel):
        return {
            "code": response.code,
            "message": response.message,
            "data": response.data.model_dump()
        }
    else:
        return response.model_dump()


def create_response(
    data: T | Any = None,
    code: int = 0,
    message: str = "success",
    status_code: int = status.HTTP_200_OK
) -> JSONResponse:
    """创建完整的JSONResponse响应"""
    content = build_response_content(data=data, code=code, message=message)
    return JSONResponse(
        content=content,
        status_code=status_code
    )


def success_response(data: T | Any = None, message: str = "success") -> JSONResponse:
    """快捷创建成功响应"""
    return create_response(data=data, message=message)


def error_response(
    message: str = "error",
    code: int = 1,
    data: T | Any = None,
    status_code: int = status.HTTP_500_INTERNAL_SERVER_ERROR
) -> JSONResponse:
    """快捷创建错误响应"""
    return create_response(
        data=data,
        code=code,
        message=message,
        status_code=status_code
    )


def success_content(data: T | Any = None, message: str = "success") -> dict:
    """只构建成功响应的内容字典"""
    return build_response_content(data=data, message=message)


def error_content(
    message: str = "error",
    code: int = 1,
    data: T | Any = None
) -> dict:
    """只构建错误响应的内容字典"""
    return build_response_content(data=data, code=code, message=message)

==> sycommon_python_lib-0.1.10.tar.gz: sycommon_python_lib-0.1.10/src/sycommon/models/base_http.py <==
from typing import TypeVar, Any, Generic
from pydantic import BaseModel, Field
from fastapi.responses import JSONResponse
from fastapi import status

# 支持任意类型的泛型约束
T = TypeVar('T')


class BaseResponseModel(BaseModel, Generic[T]):
    """基础响应模型，支持自定义状态码"""
    code: int = Field(default=0, description="业务响应码，默认0成功，1失败，支持自定义")
    message: str | None = Field(default=None, description="业务响应信息")
    success: bool = Field(default=True, description="请求是否成功")
    data: T | None = Field(default=None, description="业务响应数据，支持任意类型")
    traceId: str | None = Field(default=None, description="请求链路追踪ID")

    class Config:
        arbitrary_types_allowed = True
        from_attributes = True


def build_response_content(
    data: T | Any = None,
    code: int = 0,
    message: str = None
) -> dict:
    """
    构建响应内容字典，自动根据code判断success

    规则：
    - code为0时success=True（默认成功）
    - 其他任何code值success=False（包括200等自定义状态码）
    """
    # 成功状态仅当code为0时成立，其他任何code都视为失败
    success = code == 0 or code == 200

    response = BaseResponseModel(
        code=code,
        message=message,
        success=success,
        data=data
    )

    if isinstance(response.data, BaseModel):
        return {
            "code": response.code,
            "message": response.message,
            "success": response.success,
            "data": response.data.model_dump()
        }
    else:
        return response.model_dump()


def create_response(
    data: T | Any = None,
    code: int = 0,
    message: str = None,
    status_code: int = status.HTTP_200_OK
) -> JSONResponse:
    """创建完整响应，支持自定义业务状态码"""
    content = build_response_content(data=data, code=code, message=message)
    return JSONResponse(
        content=content,
        status_code=status_code
    )


def success_response(data: T | Any = None, code: int = 0) -> JSONResponse:
    """快捷创建成功响应（code=0, success=True）"""
    return create_response(data=data, code=code)


def error_response(
    message: str = None,
    code: int = 1,
    data: T | Any = None,
    status_code: int = status.HTTP_500_INTERNAL_SERVER_ERROR
) -> JSONResponse:
    """快捷创建错误响应，支持自定义错误码（如200）"""
    return create_response(
        data=data,
        code=code,
        message=message,
        status_code=status_code
    )


def success_content(data: T | Any = None) -> dict:
    """构建成功响应内容字典"""
    return build_response_content(data=data)


def error_content(
    message: str = None,
    code: int = 1,
    data: T | Any = None
) -> dict:
    """构建错误响应内容字典，支持自定义错误码"""
    return build_response_content(data=data, code=code, message=message)
